# PeakRDL-docx
Compile SystemRDL into a Docx (MS-Word) document


# Command line
peakrdl docx  <input_file.rdl> -o <output_file.docx> --title "Registers of the PCIe BAR1"

where:
- <input_file.rdl> indicates the input path and filename
- -o <output_file.docx> indicates the path and filename of the output file
- --title indicates the (optional) document-title
